@@ -103,7 +103,7 @@ public slots:
     virtual QList<Message> requestAllMsgs(UserId user, MsgId first = -1, MsgId last = -1, int limit = -1);
 
 protected:
-    virtual void initDbSession(QSqlDatabase &db);
+    virtual bool initDbSession(QSqlDatabase &db);
     virtual void setConnectionProperties(const QVariantMap &properties);
     inline virtual QString driverName() { return "QPSQL"; }
     inline virtual QString hostName() { return _hostName; }
