@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2012 by the Quassel Project                        *
+ *   Copyright (C) 2005-2013 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef COLUMNHANDLEITEM_H_
@@ -27,49 +27,51 @@
 
 #include "chatscene.h"
 
-class ColumnHandleItem : public QGraphicsObject {
-  Q_OBJECT
-  Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity)
+class ColumnHandleItem : public QGraphicsObject
+{
+    Q_OBJECT
+    Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity)
 
-public:
-  ColumnHandleItem(qreal width, QGraphicsItem *parent = 0);
-  virtual inline int type() const { return ChatScene::ColumnHandleType; }
+public :
+        ColumnHandleItem(qreal width, QGraphicsItem *parent = 0);
+    virtual inline int type() const { return ChatScene::ColumnHandleType; }
 
-  inline qreal width() const { return _width; }
-  inline QRectF boundingRect() const { return _boundingRect; }
-  inline qreal sceneLeft() const { return _sceneLeft; }
-  inline qreal sceneRight() const { return _sceneRight; }
+    inline qreal width() const { return _width; }
+    inline QRectF boundingRect() const { return _boundingRect; }
+    inline qreal sceneLeft() const { return _sceneLeft; }
+    inline qreal sceneRight() const { return _sceneRight; }
 
-  inline qreal opacity() const { return _opacity; }
+    inline qreal opacity() const { return _opacity; }
 
-  void setXPos(qreal xpos);
-  void setXLimits(qreal min, qreal max);
+    void setXPos(qreal xpos);
+    void setXLimits(qreal min, qreal max);
 
-  void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
 
 public slots:
-  void sceneRectChanged(const QRectF &);
-  void setOpacity(qreal opacity);
+    void sceneRectChanged(const QRectF &);
+    void setOpacity(qreal opacity);
 
 protected:
-  void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
-  void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
-  void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
-  void mousePressEvent(QGraphicsSceneMouseEvent *event);
-  void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
+    void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
+    void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
+    void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
+    void mousePressEvent(QGraphicsSceneMouseEvent *event);
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
 
 signals:
-  void positionChanged(qreal x);
+    void positionChanged(qreal x);
 
 private:
-  qreal _width;
-  qreal _sceneLeft, _sceneRight;
-  QRectF _boundingRect;
-  bool _moving;
-  qreal _offset;
-  qreal _minXPos, _maxXPos;
-  qreal _opacity;
-  QPropertyAnimation *_animation;
+    qreal _width;
+    qreal _sceneLeft, _sceneRight;
+    QRectF _boundingRect;
+    bool _moving;
+    qreal _offset;
+    qreal _minXPos, _maxXPos;
+    qreal _opacity;
+    QPropertyAnimation *_animation;
 };
 
+
 #endif
