@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2013 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef WEBPREVIEWITEM_H
@@ -25,15 +25,18 @@
 
 #include <QGraphicsItem>
 
-class WebPreviewItem : public QGraphicsItem {
+class WebPreviewItem : public QGraphicsItem
+{
 public:
-  WebPreviewItem(const QUrl &url);
-  virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
-  virtual inline QRectF boundingRect() const { return _boundingRect; }
+    WebPreviewItem(const QUrl &url);
+    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+    virtual inline QRectF boundingRect() const { return _boundingRect; }
 
 private:
-  QRectF _boundingRect;
+    QRectF _boundingRect;
 };
+
+
 #endif //#ifdef HAVE_WEBKIT
 
 #endif //WEBPREVIEWITEM_H
